gchecky.model.areas_t

Package gchecky :: Module model :: Class areas_t |
[hide private]
[frames] | no frames]

# Class areas_t

source code

    object --+
             |
     gxml.Node --+
                 |
                areas_t

Known Subclasses:
  allowed_areas_t, excluded_areas_t

Represents a list of regions.

    >>> test_node(
    ...   areas_t(
    ...     states = ['LA', 'NY'],
    ...     country_areas = ['ALL', 'CONTINENTAL_48']
    ...   )
    ... ,
    ... '''
    ... <node>
    ... <us-state-area>
    ...   <state>LA</state>
    ... </us-state-area>
    ... <us-state-area>
    ...   <state>NY</state>
    ... </us-state-area>
    ... <us-country-area>
    ...   <country-area>ALL</country-area>
    ... </us-country-area>
    ... <us-country-area>
    ...   <country-area>CONTINENTAL_48</country-area>
    ... </us-country-area>
    ... </node>
    ... '''
    ... )

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| states = `List:PATH():OP`...``
| zip_patterns = `List:PATH():OP`...``
| country_areas = `List:PATH():OPT:VALS("CONTINENTAL_48","FULL_50`...``
| _fields = ``{``'``country_areas``'``:` List:PATH():OPT:VALS("CONTINENTAL_`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### states Value:
      List:PATH():OPT:[
          String:PATH(us-state-area/state):REQ
      ]

  ### zip_patterns Value:
      List:PATH():OPT:[
          String:PATH(us-zip-area/zip-pattern):REQ
      ]

  ### country_areas Value:
      List:PATH():OPT:VALS("CONTINENTAL_48","FULL_50_STATES","ALL"):[
          String:PATH(us-country-area/country-area):REQ
      ]

  ### _fields list of meta-Fields of this class. Value:
      {'country_areas': List:PATH():OPT:VALS("CONTINENTAL_48","FULL_50_STATE
      S","ALL"):[
          String:PATH(us-country-area/country-area):REQ
      ],
       'states': List:PATH():OPT:[
          String:PATH(us-state-area/state):REQ
      ],
       'zip_patterns': List:PATH():OPT:[
      ...